# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-12 07:34
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_coin', '0012_auto_20181112_1527'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='pic',
            field=models.ImageField(blank=True, null=True, upload_to='bee_django_coin/shop/item', verbose_name='\u5546\u54c1\u56fe\u7247'),
        ),
    ]
